@@ -16,7 +16,7 @@ FUEL = [autogas, diesel, erdgas, superplus, super, normal]
 
 class ITBObject:
     def __init__(self):
-        self.version = "1.0.14"
+        self.version = "1.0.15"
         self.author = "Ludy87"
         self.project = "Ich tanke billig"
         self.page = "https://www.astra-g.org/"
@@ -105,7 +105,7 @@ def getStations(kraftstoff = diesel, place = '123', limit = '-1', asJson = False
     else:
         return me
 
-def getStationsA(kraftstoffe = FUEL, place_plz = '123', limit = -1):
+def getStationsA(kraftstoffe = FUEL, place_plz = '123', limit = -1, asJson = False):
     stations = []
     for kraftstoff in kraftstoffe:
         me = ITBObject()
@@ -191,4 +191,6 @@ def getStationsA(kraftstoffe = FUEL, place_plz = '123', limit = -1):
                     elif (FUEL[FUEL.index(kraftstoff)] == FUEL[5]):
                         me.normal.append(json_data)
         stations.append(me)
+    if asJson:
+        return toJSON(stations)
     return (stations)
